ModelNode class

Describes a 3D model to load into the scene.

Constructors

ModelNode({required String modelPath, double x = 0.0, double y = 0.0, double z = 0.0, double scale = 1.0})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
modelPath String
Asset path or URL to the glTF/GLB model file.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
Uniform scale factor applied to the model.
final
x double
X position in world space.
final
y double
Y position in world space.
final
z double
Z position in world space.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited