isAttached property
bool
get
isAttached
Whether this controller is attached to a platform view.
Implementation
bool get isAttached => _channel != null && !_disposed;
Whether this controller is attached to a platform view.
bool get isAttached => _channel != null && !_disposed;