GeometryNode class
Describes a geometry primitive in the scene.
Note: Geometry nodes are acknowledged by the native bridge but rendering is not yet implemented. This is a forward-looking API placeholder.
Constructors
Properties
- color → int
-
Fill color as an ARGB integer (e.g. 0xFF6750A4).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
final
- type → String
-
Geometry type: 'cube', 'sphere', 'cylinder', or 'plane'.
final
- x → double
-
final
- y → double
-
final
- z → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited