LightNode class
Describes a light source in the scene.
Note: Light nodes are acknowledged by the native bridge but custom light configuration is not yet implemented. Scenes use sensible defaults.
Constructors
Properties
- color → int
-
Light color as an ARGB integer.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- intensity → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Light type: 'directional', 'point', or 'spot'.
final
- x → double
-
final
- y → double
-
final
- z → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited